==> akelpad-2.1.6-src.zip: lang_en.cpp <==
char APP_SHORT_TITLE[]="AkelPad";
char APP_FULL_TITLE[]="AkelPad2";

char STR_DUMMY_NAME[]="AkelPad Synchronizing Class";

char STR_MODE_INSERT[]="Insert";
char STR_MODE_OVERLAP[]="Overlay";
char STR_MODIFIED[]="Modified";

char STR_CP_WINDOWS[]="Windows (ANSI)";
char STR_CP_DOS[]="DOS (OEM)";
char STR_CP_KOI[]="KOI8-R";
char STR_CP_UNICODE_UCS2_LE[]="Unicode (UCS-2 little endian)";
char STR_CP_UNICODE_UCS2_BE[]="Unicode (UCS-2 big endian)";
char STR_CP_UNICODE_UTF8[]="Unicode (UTF-8)";

char STR_FILE_FILTER[]="Text files (*.txt)\0*.txt\0All files (*.*)\0*.*\0\0";

char STR_DOCNAME[]="AkelPad Document";

char STR_HOMEPAGE[]="http://akelpad.net.ru/english.shtml";

//akelpad.cpp messages
char MSG_ERROR_LOADING_DLL[]="Cannot load RICHED20.DLL.";
char MSG_ERROR_IN_MESSAGE_QUEUE[]="Error in message queue.";
char MSG_ERROR_LIMIT_REACHED[]="Action couldn't be performed due to text limit.\nThe limit will be increased.";
char MSG_ERROR_NOT_ENOUGH_MEMORY_FOR_RICHEDIT[]="Error allocating memory for edit control.";
char MSG_ERROR_NOT_ENOUGH_MEMORY[]="Not enough memory.";


//edit.cpp messages
char MSG_DOCUMENT_CHANGED[]="Document was modified. Do you want to save it?";
char MSG_FILE_WILL_BE_REOPENED[]="File will be reopened, all changes will be lost.";
char MSG_WHETHER_APPEND_HEADER[]="Unicode files usually have a mark in the beginning, which helps to identify codepage. This file hasn't. Do you want to add it?";
char MSG_ERROR_IO[]="Input/output error.";
char MSG_ERROR_CANNOT_TRANSLATE[]="Error: cannot recode text.";
char MSG_ERROR_CANNOT_OPEN_FILE[]="Cannot open file.";
char MSG_ERROR_SYNTAX[]="Syntax error.";
char MSG_TITLE_SAVING_IN_UNICODE[]="Unicode warning";
char MSG_WRONG_STRING[]="Invalid line number";
char MSG_ERROR_PRINT[]="Cannot print document";

//codepage.cpp messages
char MSG_WRONG_CODEPAGE[]="Wrong codepage.";
char MSG_CP_UNIMPLEMENTED[]="This codepage isn't implemented.";

==> akelpad-2.1.8a-src.zip: lang_en.cpp <==
char APP_SHORT_TITLE[]="AkelPad";
char APP_FULL_TITLE[]="AkelPad2";

char STR_DUMMY_NAME[]="AkelPad Synchronizing Class";

char STR_MODE_INSERT[]="Insert";
char STR_MODE_OVERLAP[]="Overlay";
char STR_MODIFIED[]="Modified";

char STR_CP_WINDOWS[]="Windows (ANSI)";
char STR_CP_DOS[]="DOS (OEM)";
char STR_CP_KOI[]="KOI8-R";
char STR_CP_UNICODE_UCS2_LE[]="Unicode (UCS-2 little endian)";
char STR_CP_UNICODE_UCS2_BE[]="Unicode (UCS-2 big endian)";
char STR_CP_UNICODE_UTF8[]="Unicode (UTF-8)";

char STR_FILE_FILTER[]="Text files (*.txt)\0*.txt\0All files (*.*)\0*.*\0\0";

char STR_DOCNAME[]="AkelPad Document";

char STR_HOMEPAGE[]="http://akelpad.sourceforge.net";

//akelpad.cpp messages
char MSG_ERROR_LOADING_DLL[]="Cannot load RICHED20.DLL.";
char MSG_ERROR_IN_MESSAGE_QUEUE[]="Error in message queue.";
char MSG_ERROR_LIMIT_REACHED[]="Action couldn't be performed due to text limit.\nThe limit will be increased.";
char MSG_ERROR_NOT_ENOUGH_MEMORY_FOR_RICHEDIT[]="Error allocating memory for edit control.";
char MSG_ERROR_NOT_ENOUGH_MEMORY[]="Not enough memory.";


//edit.cpp messages
char MSG_DOCUMENT_CHANGED[]="Document was modified. Do you want to save it?";
char MSG_FILE_WILL_BE_REOPENED[]="File will be reopened, all changes will be lost.";
char MSG_WHETHER_APPEND_HEADER[]="Unicode files usually have a mark in the beginning, which helps to identify codepage. This file hasn't. Do you want to add it?";
char MSG_ERROR_IO[]="Input/output error.";
char MSG_ERROR_CANNOT_TRANSLATE[]="Error: cannot recode text.";
char MSG_ERROR_CANNOT_OPEN_FILE[]="Cannot open file.";
char MSG_ERROR_SYNTAX[]="Syntax error.";
char MSG_TITLE_SAVING_IN_UNICODE[]="Unicode warning";
char MSG_WRONG_STRING[]="Invalid line number";
char MSG_ERROR_PRINT[]="Cannot print document";

//codepage.cpp messages
char MSG_WRONG_CODEPAGE[]="Wrong codepage.";
char MSG_CP_UNIMPLEMENTED[]="This codepage isn't implemented.";
